@@ -5,14 +5,14 @@ use warnings;
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '5.64';
+    $Validation::Class::VERSION = '5.68';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.64';    # VERSION
+our $VERSION = '5.68';    # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -315,14 +315,33 @@ sub load {
 
     }
 
-    # attached base classes (configs)
-    if ($data->{base}) {
+    # attach roles
+    if ($data->{base} || $data->{role} || $data->{roles}) {
 
-        $data->{base} = [$data->{base}] unless "ARRAY" eq ref $data->{base};
+        if ($data->{roles}) {
 
-        if (@{$data->{base}}) {
+            $data->{roles} = [$data->{roles}]
+              unless "ARRAY" eq ref $data->{roles};
 
-            foreach my $class (@{$data->{base}}) {
+        }
+
+        else {
+
+            $data->{roles} = [];
+
+        }
+
+        push @{$data->{roles}},
+          ("ARRAY" eq ref $data->{role} ? @{$data->{role}} : $data->{role})
+          if defined $data->{role};
+
+        push @{$data->{roles}},
+          ("ARRAY" eq ref $data->{base} ? @{$data->{base}} : $data->{base})
+          if defined $data->{base};
+
+        if (@{$data->{roles}}) {
+
+            foreach my $class (@{$data->{roles}}) {
 
                 # require plugin
                 my $file = $class;
@@ -524,7 +543,7 @@ sub new {
                       :
 
                       # validate profile
-                      sub { $self->validate_profile($input, @_) };
+                      sub { $self->validate_profile($input, @args) };
 
                 }
 
@@ -532,7 +551,7 @@ sub new {
 
                     if ("CODE" eq ref $using) {
 
-                        my $error = "method $key failed to validate";
+                        my $error = "Method $key failed to validate";
 
                         # run input validation
                         if ("CODE" eq ref $validator) {
@@ -567,7 +586,7 @@ sub new {
                               :
 
                               # validate profile
-                              sub { $self->validate_profile($output, @_) };
+                              sub { $self->validate_profile($output, @args) };
 
                             confess $error
                               . " output, "
@@ -582,7 +601,7 @@ sub new {
 
                     else {
 
-                        confess "Error executing $key, no associates coderef";
+                        confess "Error executing $key, no associated coderef";
 
                     }
 
@@ -664,7 +683,7 @@ Validation::Class - Low-Fat Full-Flavored Data Modeling and Validation Framework
 
 =head1 VERSION
 
-version 5.64
+version 5.68
 
 =head1 SYNOPSIS
 
@@ -709,7 +728,9 @@ version 5.64
         min_symbols => 1
     };
     
-    has attitude => 1; # just an attr
+    # just an attr
+    
+    has attitude => 1; 
     
     # self-validating method
     
@@ -758,7 +779,7 @@ centralizes data validation rules to ensure consistency through DRY
     unless ($user->validate('login', 'pass')){
     
         # do something with ... $input->errors;
-        
+    
     }
 
 =head1 DESCRIPTION
@@ -767,7 +788,7 @@ Validation::Class is much more than a simple data validation framework, in-fact
 it is more of a data modeling framework and can be used as an alternative to
 minimalistic object systems such as L<Moo>, L<Mo>, etc.
 
-Validation::Class aims to provide the building blocks for easily defining
+Validation::Class aims to provide the building blocks for easily definable
 self-validating data models.
 
 When fields (attributes with validation rules) are defined, accessors are
@@ -787,7 +808,7 @@ The attribute keyword (or has) creates a class attribute.
     
     use Validate::Class;
     
-    has 'attitude' => sub {
+    attribute 'attitude' => sub {
         
         return $self->bothered ? 1 : 0 
         
@@ -927,8 +948,10 @@ The coderef should also return the transformed value.
 
 =head2 load
 
-The load keyword (or set), which can also be used as a method, provides options for
-further configuring the calling class. 
+The load keyword (or set), which can also be used as a method, provides options
+for extending the current class by attaching other L<Validation::Class> classes
+as roles. The process of applying roles to the current class mainly involve
+copying the role's methods and configuration.
 
     package MyApp;
     
@@ -1013,6 +1036,26 @@ more about plugins at L<Validation::Class::Cookbook>.
     
     1;
 
+The C<load.roles> option is used to load and inherit functionality from child
+classes, these classes should be used and thought-of as roles. Any validation
+class can be used as a role with this option.
+
+    package MyVal::User;
+    
+    load {
+        role => 'MyVal::Person'
+    };
+    
+    # or
+    
+    load {
+        roles => [
+            'MyVal::Person'
+        ]
+    };
+    
+    1;
+
 =head2 method
 
 The method keyword (or mth) is used to create an auto-validating method. Similar
@@ -1027,7 +1070,7 @@ to proceed.
     method 'register' => {
     
         input  => ['name', '+email', 'login', '+password'],
-        output => ['+id'], # optional output validation
+        output => ['+id'], # optional output validation, dies on failure
         using  => sub {
         
             my ($self, @args) = @_;
@@ -1162,6 +1205,27 @@ the calling class. The engine-class is the role that provides all of the data
 validation functionality, please see L<Validation::Class::Engine> for more
 information on specific methods, and attributes.
 
+=head2 before
+
+ before foo => sub { ... };
+
+See L<< Class::Method::Modifiers/before method(s) => sub { ... } >> for full
+documentation.
+
+=head2 around
+
+ around foo => sub { ... };
+
+See L<< Class::Method::Modifiers/around method(s) => sub { ... } >> for full
+documentation.
+
+=head2 after
+
+ after foo => sub { ... };
+
+See L<< Class::Method::Modifiers/after method(s) => sub { ... } >> for full
+documentation.
+
 =head1 AUTHOR
 
 Al Newkirk <awncorp@cpan.org>
