@@ -2,14 +2,14 @@
 
 package Validation::Class::Engine;
 {
-    $Validation::Class::Engine::VERSION = '5.64';
+    $Validation::Class::Engine::VERSION = '5.68';
 }
 
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '5.64';    # VERSION
+our $VERSION = '5.68';    # VERSION
 
 use Carp 'confess';
 use Array::Unique;
@@ -220,21 +220,22 @@ sub class {
 
     my ($self, $class, %args) = @_;
 
-#confess 'Relative class does not exist, please ensure you are calling the class '.
-#    'method from the parent class, i.e. the class where you called the '.
-#    'load_classes method' unless defined $self->relatives->{$class};
+    return undef unless defined $self->relatives->{$class};
 
-    return unless defined $self->relatives->{$class};
-
-    my %defaults = (
-        'params'         => $self->params,
-        'stashed'        => $self->stashed,
-        'ignore_unknown' => $self->ignore_unknown,
-        'report_unknown' => $self->report_unknown,
-        'hash_inflator'  => $self->hash_inflator
+    my @attrs = qw(
+      hash_inflator
+      ignore_failure
+      ignore_unknown
+      params
+      report_failure
+      report_unknown
+      stashed
     );
 
+    my %defaults = (map { $_ => $self->$_ } @attrs);
+
     my $child = $self->relatives->{$class}->new(merge(\%args, \%defaults));
+
     my $delimiter = $self->hash_inflator->{'HashDelimiter'};
 
     $delimiter =~ s/([\.\+\-\:\,\\\/])/\\$1/g;
@@ -271,7 +272,7 @@ sub check_field {
             my $death_cert = "The $_ directive supplied by the $field "
               . "field is not supported";
 
-            $self->xxx_suicide_by_unknown_field($death_cert);
+            $self->_error_unknown_field($death_cert);
         }
 
     }
@@ -290,12 +291,12 @@ sub check_mixin {
         if (!defined $directives->{$_}) {
             my $death_cert =
               "The $_ directive supplied by the $mixin mixin is not supported";
-            $self->xxx_suicide_by_unknown_field($death_cert);
+            $self->_error_unknown_field($death_cert);
         }
         if (!$directives->{$_}) {
             my $death_cert =
               "The $_ directive supplied by the $mixin mixin is empty";
-            $self->xxx_suicide_by_unknown_field($death_cert);
+            $self->_error_unknown_field($death_cert);
         }
     }
 
@@ -1573,7 +1574,7 @@ sub use_mixin {
         if (defined $self->{mixins}->{$mixin}) {
 
             $self->fields->{$field} =
-              $self->xxx_merge_field_with_mixin($self->fields->{$field},
+              $self->_merge_mixin($self->fields->{$field},
                 $self->{mixins}->{$mixin});
 
         }
@@ -1598,8 +1599,7 @@ sub use_mixin_field {
       if defined $self->fields->{$target}->{label};
 
     $self->fields->{$target} =
-      $self->xxx_merge_field_with_field($self->fields->{$target},
-        $self->fields->{$field});
+      $self->_merge_field($self->fields->{$target}, $self->fields->{$field});
 
     $self->fields->{$target}->{name}  = $name  if defined $name;
     $self->fields->{$target}->{label} = $label if defined $label;
@@ -1813,7 +1813,7 @@ sub validate {
             while (my ($name, $param) = each(%{$self->params})) {
 
                 if (!defined $self->fields->{$name}) {
-                    $self->xxx_suicide_by_unknown_field(
+                    $self->_error_unknown_field(
                         "Data validation field $name does not exist");
                     next;
                 }
@@ -1872,7 +1872,7 @@ sub validate {
 
                 if (!defined $self->fields->{$field_name}) {
 
-                    $self->xxx_suicide_by_unknown_field(
+                    $self->_error_unknown_field(
                         "Data validation field $field_name does not exist");
                     next;
 
@@ -1937,7 +1937,7 @@ sub validate {
 
                 if (!defined $self->fields->{$field_name}) {
 
-                    $self->xxx_suicide_by_unknown_field(
+                    $self->_error_unknown_field(
                         "Data validation field $field_name does not exist");
                     next;
 
@@ -2048,7 +2048,7 @@ sub validate_profile {
 
 }
 
-sub xxx_suicide_by_unknown_field {
+sub _error_unknown_field {
 
     my ($self, $error) = @_;
 
@@ -2066,7 +2066,7 @@ sub xxx_suicide_by_unknown_field {
 
 }
 
-sub xxx_merge_field_with_mixin {
+sub _merge_mixin {
 
     my ($self, $field, $mixin) = @_;
 
@@ -2121,7 +2121,7 @@ sub xxx_merge_field_with_mixin {
 
 }
 
-sub xxx_merge_field_with_field {
+sub _merge_field {
 
     my ($self, $field, $mixin_field) = @_;
 
@@ -2185,7 +2185,7 @@ Validation::Class::Engine - Data Validation Engine for Validation::Class
 
 =head1 VERSION
 
-version 5.64
+version 5.68
 
 =head1 SYNOPSIS
 
@@ -2234,7 +2234,7 @@ version 5.64
     # an auto-validating method
     mth 'register'  => {
         
-        input => [qw/+login +password/],
+        input => 'registration',
         using => sub {
             
             my ($self, @args) = shift;
